EEnum
*****

EEnum is an extension to the python enum library.  It adds some features to
enum and wraps Enum3.4 so it can be used invisibly across python versions.

Installation
============

.. code-block:: bash

    $ pip install eenum

Supports
========

Python eenum has been tested with Python 2.7, 3.5, and 3.6

Docs & Source
=============

Docs: http://eenum.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/eenum
